@@ -1,5 +1,7 @@
 package Pisg::HTMLGenerator;
 
+# $Id: HTMLGenerator.pm,v 1.172 2005/08/11 17:38:36 df7cb Exp $
+#
 # Copyright and license, as well as documentation(POD) for this module is
 # found at the end of the file.
 
@@ -112,7 +114,7 @@ sub create_output
 
     if ($self->{cfg}->{showbignumbers}) {
         $self->_headline($self->_template_text('bignumtopic'));
-        _html("<table width=\"$self->{cfg}->{tablewidth}\">\n"); # Needed for sections
+        _html("<table width=\"$self->{cfg}->{tablewidth}\">"); # Needed for sections
         $self->_questions();
         $self->_shoutpeople();
         $self->_capspeople();
@@ -159,7 +161,7 @@ sub create_output
 
     if ($self->{cfg}->{showbignumbers}) {
         $self->_headline($self->_template_text('othernumtopic'));
-        _html("<table width=\"$self->{cfg}->{tablewidth}\">\n"); # Needed for sections
+        _html("<table width=\"$self->{cfg}->{tablewidth}\">"); # Needed for sections
         $self->_gotkicks();
         $self->_mostkicks();
         $self->_mostop() if $self->{cfg}->{showops};
@@ -174,7 +176,7 @@ sub create_output
 
     if ($self->{cfg}->{showtopics}) {
         $self->_headline($self->_template_text('latesttopic'));
-        _html("<table width=\"$self->{cfg}->{tablewidth}\">\n"); # Needed for sections
+        _html("<table width=\"$self->{cfg}->{tablewidth}\">"); # Needed for sections
 
         $self->_lasttopics();
 
@@ -225,7 +227,7 @@ sub _htmlheader
 
     my $title = $self->_template_text('pagetitle1', %hash);
     if($self->{cfg}->{colorscheme} ne "none") {
-        print OUTPUT <<HTML;
+        _html( <<HTML );
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html>
 <head>
@@ -312,7 +314,7 @@ sub _htmlfooter
     my $author_text = $self->_template_text('author', %hash);
     my $stats_text = $self->_template_text('stats_gen_in', %hash);
 
-    print OUTPUT <<HTML;
+    _html( <<HTML );
 <span class="small">
 $stats_gen<br />
 $author_text<br />
@@ -321,7 +323,7 @@ $stats_text
 HTML
 
     if($self->{cfg}->{colorscheme} ne "none") {
-        print OUTPUT <<HTML;
+        _html( <<HTML );
 </div>
 </body>
 </html>
@@ -333,7 +335,7 @@ sub _headline
 {
     my $self = shift;
     my ($title) = (@_);
-    print OUTPUT <<HTML;
+    _html( <<HTML );
    <br />
    <table width="$self->{cfg}->{headwidth}" cellpadding="1" cellspacing="0" border="0">
     <tr>
@@ -357,6 +359,7 @@ sub _pageheader
         return;
     }
     while (<PAGEHEAD>) {
+        chomp;
         _html($_);
     }
     close(PAGEHEAD);
@@ -370,6 +373,7 @@ sub _pagefooter
         return;
     }
     while (<PAGEFOOT>) {
+        chomp;
         _html($_);
     }
     close(PAGEFOOT);
@@ -400,7 +404,7 @@ sub _activedays
     );
     $self->_headline($self->_template_text('dailyactivitytopic', %hash));
 
-    _html("<table border=\"0\"><tr>\n");
+    _html("<table border=\"0\"><tr>");
 
     for (my $day = $days - $ndays + 1; $day <= $days ; $day++) {
         my $lines = $self->{stats}->{day_lines}[$day];
@@ -415,7 +419,7 @@ sub _activedays
 
             }
         }
-        _html("</td>\n");
+        _html("</td>");
     }
 
     _html("</tr><tr>");
@@ -454,10 +458,10 @@ sub _activetimes
         my $image = "pic_v_".(int($hour/6)*6);
         $image = $self->{cfg}->{$image};
 
-        $output{$hour} = "<td align=\"center\" valign=\"bottom\" class=\"asmall\">$percent%<br /><img src=\"$self->{cfg}->{piclocation}/$image\" width=\"15\" height=\"$size\" alt=\"$lines_per_hour\" title=\"$lines_per_hour\"/></td>\n" if $size;
+        $output{$hour} = "<td align=\"center\" valign=\"bottom\" class=\"asmall\">$percent%<br /><img src=\"$self->{cfg}->{piclocation}/$image\" width=\"15\" height=\"$size\" alt=\"$lines_per_hour\" title=\"$lines_per_hour\"/></td>" if $size;
     }
 
-    _html("<table border=\"0\"><tr>\n");
+    _html("<table border=\"0\"><tr>");
 
     for ($b = 0; $b < 24; $b++) {
         $a = sprintf("%02d", $b);
@@ -557,7 +561,11 @@ sub _activenicks
             $visiblenick = $self->_format_word($nick);
         }
 
-        my $color = $self->generate_colors($c);
+        my $style = '';
+        if ($self->{cfg}->{colorscheme} ne 'none') {
+            $style = "style=\"background-color: ". $self->generate_colors($c) ."\"";
+        }
+
         my $class = 'rankc';
         if ($c == 1) {
             $class = 'hirankc';
@@ -583,39 +591,39 @@ sub _activenicks
         my $w = $self->{stats}->{words}{$nick} ? $self->{stats}->{words}{$nick} : 0;
         my $ch   = $self->{stats}->{lengths}{$nick};
        my $sex = $self->{users}->{sex}{$nick};
-       _html("<td style=\"background-color: $color\""
+       _html("<td $style"
        . ($sex ? ($sex eq 'm' ? " class=\"male\">"
        : ($sex eq 'f' ? " class=\"female\">" : " class=\"bot\">")) : ">")
        ."$visiblenick</td>"
         . ($self->{cfg}->{showlines} ? 
          ($self->{cfg}->{showlinetime} ?
-        "<td style=\"background-color: $color\" nowrap=\"nowrap\">".$self->_user_linetimes($nick,$active[0])."</td>"
-        : "<td style=\"background-color: $color\">$line</td>") : "")
+        "<td $style nowrap=\"nowrap\">".$self->_user_linetimes($nick,$active[0])."</td>"
+        : "<td $style>$line</td>") : "")
         . ($self->{cfg}->{showtime} ?
-        "<td style=\"background-color: $color\">".$self->_user_times($nick)."</td>"
+        "<td $style>".$self->_user_times($nick)."</td>"
         : "")
         . ($self->{cfg}->{showwords} ?
            ($self->{cfg}->{showwordtime} ?
-           "<td style=\"background-color: $color\" nowrap=\"nowrap\">".$self->_user_wordtimes($nick,$active[0])."</td>"
-           : "<td style=\"background-color: $color\">$w</td>")
+           "<td $style nowrap=\"nowrap\">".$self->_user_wordtimes($nick,$active[0])."</td>"
+           : "<td $style>$w</td>")
         : "")
         . ($self->{cfg}->{showwpl} ?
-        "<td style=\"background-color: $color\">".sprintf("%.1f",$w/$line)."</td>"
+        "<td $style>".sprintf("%.1f",$w/$line)."</td>"
         : "")
         . ($self->{cfg}->{showcpl} ?
-        "<td style=\"background-color: $color\">".sprintf("%.1f",$ch/$line)."</td>"
+        "<td $style>".sprintf("%.1f",$ch/$line)."</td>"
         : "")
         . ($self->{cfg}->{showlastseen} ?
-        "<td style=\"background-color: $color\">$lastseen</td>"
+        "<td $style>$lastseen</td>"
         : "")
         . ($self->{cfg}->{showrandquote} ?
-        "<td style=\"background-color: $color\">\"$randomline\"</td>"
+        "<td $style>\"$randomline\"</td>"
         : "")
         );
         if ($self->{cfg}->{userpics} && $i % $self->{cfg}->{userpics} == 0) {
             for my $ii (0 .. $self->{cfg}->{userpics} - 1) {
                 last if $i + $ii >= $self->{cfg}->{activenicks};
-                $self->_user_pic($active[$i + $ii], $color);
+                $self->_user_pic($active[$i + $ii], $style);
             }
         }
         _html("</tr>");
@@ -697,7 +705,7 @@ sub generate_colors
 sub _html
 {
     my $html = shift;
-    print OUTPUT "$html\n";
+    print OUTPUT "$html\n" or die "Could not write to disk: $!\n";
 }
 
 sub _questions
@@ -2036,7 +2044,7 @@ sub _legend
     _html("<td align=\"center\" class=\"asmall\"><img src=\"$self->{cfg}->{piclocation}/$self->{cfg}->{pic_h_6}\" width=\"40\" height=\"15\" align=\"middle\" alt=\"6-11\" /> = 6-11</td>");
     _html("<td align=\"center\" class=\"asmall\"><img src=\"$self->{cfg}->{piclocation}/$self->{cfg}->{pic_h_12}\" width=\"40\" height=\"15\" align=\"middle\" alt=\"12-17\" /> = 12-17</td>");
     _html("<td align=\"center\" class=\"asmall\"><img src=\"$self->{cfg}->{piclocation}/$self->{cfg}->{pic_h_18}\" width=\"40\" height=\"15\" align=\"middle\" alt=\"18-23\" /> = 18-23</td>");
-    _html("</tr></table>\n");
+    _html("</tr></table>");
 }
 
 
@@ -2155,12 +2163,12 @@ sub _user_pic
 {
     my $self = shift;
     my $nick  = shift;
-    my $color  = shift;
+    my $style  = shift;
 
     return unless $self->{users}->{userpics}{$nick} or $self->{cfg}->{defaultpic};
 
     my $rowspan = $self->{cfg}->{userpics} ? " rowspan=\"$self->{cfg}->{userpics}\"" : "";
-    my $output = "<td style=\"background-color: $color\" align=\"center\" valign=\"middle\"$rowspan>";
+    my $output = "<td $style align=\"center\" valign=\"middle\"$rowspan>";
 
     my $biguserpic = $self->{users}->{biguserpics}{$nick};
     if ($biguserpic) {
